@@ -11,13 +11,12 @@ import functools
 import traceback
 
 from . import stream
-from . import compat
 from . import execute
 
 EXTRA_MESSAGE = """\
 ---
 This console is running in an asyncio event loop.
-It allows you to wait for coroutines using the '{0}' syntax.
+It allows you to wait for coroutines using the 'await' syntax.
 Try: await asyncio.sleep(1, result=3)
 ---"""
 
@@ -27,8 +26,6 @@ try:
 except NameError:
     help_function = None
 
-current_task = asyncio.Task.current_task if compat.PY36 else asyncio.current_task
-
 
 class AsynchronousCompiler(codeop.CommandCompiler):
     def __init__(self):
@@ -110,7 +107,9 @@ class AsynchronousConsole(code.InteractiveConsole):
 
     async def runcode(self, code):
         try:
-            await execute.aexec(code, self.locals, self)
+            await execute.aexec(
+                code, local=self.locals, stream=self, filename=self.filename
+            )
         except SystemExit:
             raise
         except BaseException:
@@ -126,7 +125,7 @@ class AsynchronousConsole(code.InteractiveConsole):
             task._wakeup(task._fut_waiter)
 
     def add_sigint_handler(self):
-        task = current_task(loop=self.loop)
+        task = asyncio.current_task(loop=self.loop)
         try:
             self.loop.add_signal_handler(signal.SIGINT, self.handle_sigint, task)
         except NotImplementedError:
